# Библиотека MiRouter

MiRouter - это библиотека Python для взаимодействия с маршрутизаторами Xiaomi через их веб-API. Она предоставляет методы для аутентификации, получения информации о устройствах, перезагрузки маршрутизатора, проверки статуса интернета и выхода из системы.

## Установка

Вы можете установить библиотеку MiRouter с помощью pip:

```bash
pip install MiRouter
```

## Использование

```python
from mi_router import MiRouter

# Инициализация экземпляра MiRouter
router = MiRouter(host='ip_вашего_маршрутизатора', username='ваше_имя_пользователя', password='ваш_пароль')

# Аутентификация
if router.login():
    print("Аутентификация прошла успешно!")
else:
    print("Аутентификация не удалась!")

# Получение списка устройств
devices = router.get_device_list()
if devices:
    print("Список устройств:", devices)
else:
    print("Не удалось получить список устройств!")

# Перезагрузка маршрутизатора
if router.reboot():
    print("Маршрутизатор успешно перезагружен!")
else:
    print("Не удалось перезагрузить маршрутизатор!")

# Получение статуса интернета
internet_status = router.get_internet_status()
if internet_status:
    print("Статус интернета:", internet_status)
else:
    print("Не удалось получить статус интернета!")

# Выход из системы
router.logout()
print("Выход из системы выполнен успешно!")
```

## Методы

#### `__init__(self, host: str, username: str, password: str) -> None`

Инициализирует экземпляр MiRouter с предоставленным IP-адресом хоста, именем пользователя и паролем.

#### `login(self) -> bool`

Аутентифицирует пользователя в маршрутизаторе. Возвращает `True`, если аутентификация прошла успешно, в противном случае `False`.

#### `get_device_list(self) -> Optional[Dict[str, Any]]`

Получает список устройств, подключенных к маршрутизатору. Возвращает словарь с информацией об устройствах или `None`, если операция не удалась.

#### `reboot(self) -> bool`

Перезагружает маршрутизатор. Возвращает `True`, если запрос на перезагрузку успешен, в противном случае `False`.

#### `get_internet_status(self) -> Optional[Dict[str, Any]]`

Получает статус интернета маршрутизатора. Возвращает словарь с информацией о статусе интернета или `None`, если операция не удалась.

#### `logout(self) -> None`

Выходит из системы пользователя в сеансе маршрутизатора.

## Лицензия

Этот проект распространяется под лицензией MIT - см. файл [LICENSE](LICENSE) для получения дополнительной информации.